@@ -114,6 +114,10 @@ pub struct Job {
     /// Job value, bigger value - more chances for assignment.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub value: Option<f64>,
+
+    /// Job group: jobs of the same group are assigned to the same tour or unassigned.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub group: Option<String>,
 }
 
 /// A plan specifies work which has to be done.
@@ -303,13 +307,28 @@ pub struct VehicleBreakPlace {
     pub tag: Option<String>,
 }
 
+/// Vehicle break policy.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+pub enum VehicleBreakPolicy {
+    /// Allows to skip break if actual tour schedule doesn't intersect with vehicle time window.
+    #[serde(rename(deserialize = "skip-if-no-intersection", serialize = "skip-if-no-intersection"))]
+    SkipIfNoIntersection,
+    /// Allows to skip break if vehicle arrives before break's time window end.
+    #[serde(rename(deserialize = "skip-if-arrival-before-end", serialize = "skip-if-arrival-before-end"))]
+    SkipIfArrivalBeforeEnd,
+}
+
 /// Vehicle break.
 #[derive(Clone, Deserialize, Debug, Serialize)]
 pub struct VehicleBreak {
     /// Break time.
     pub time: VehicleBreakTime,
-    /// Vehicle break place.
+
+    /// Vehicle break places.
     pub places: Vec<VehicleBreakPlace>,
+
+    /// Specifies vehicle break policy.
+    pub policy: Option<VehicleBreakPolicy>,
 }
 
 /// Specifies a vehicle type.
@@ -407,6 +426,10 @@ pub enum Objective {
     /// An objective to maximize value of served jobs.
     #[serde(rename(deserialize = "maximize-value", serialize = "maximize-value"))]
     MaximizeValue {
+        /// Specifies a weight of skipped breaks. Default value is 100.
+        #[serde(rename = "camelCase")]
+        breaks: Option<f64>,
+
         /// A factor to reduce value cost compared to max cost.
         /// Default value is 0.1.
         #[serde(rename = "camelCase")]
@@ -416,7 +439,7 @@ pub enum Objective {
     /// An objective to minimize amount of unassigned jobs.
     #[serde(rename(deserialize = "minimize-unassigned", serialize = "minimize-unassigned"))]
     MinimizeUnassignedJobs {
-        /// A multiplier to increase/decrease break is importance.
+        /// A skipped break weight to increase/decrease break is importance.
         /// Default is 1.
         #[serde(skip_serializing_if = "Option::is_none")]
         breaks: Option<f64>,
