@@ -3,6 +3,7 @@
 mod writer_test;
 
 use crate::format::coord_index::CoordIndex;
+use crate::format::solution::activity_matcher::get_job_tag;
 use crate::format::solution::model::Timing;
 use crate::format::solution::*;
 use crate::format::*;
@@ -37,13 +38,13 @@ pub trait PragmaticSolution<W: Write> {
 
 impl<W: Write> PragmaticSolution<W> for Solution {
     fn write_pragmatic_json(&self, problem: &Problem, writer: BufWriter<W>) -> Result<(), String> {
-        let solution = create_solution(problem, &self, None);
+        let solution = create_solution(problem, self, None);
         serialize_solution(writer, &solution).map_err(|err| err.to_string())?;
         Ok(())
     }
 
     fn write_geo_json(&self, problem: &Problem, writer: BufWriter<W>) -> Result<(), String> {
-        let solution = create_solution(problem, &self, None);
+        let solution = create_solution(problem, self, None);
         serialize_solution_as_geojson(writer, problem, &solution).map_err(|err| err.to_string())?;
         Ok(())
     }
@@ -176,12 +177,15 @@ fn create_tour(problem: &Problem, route: &Route, coord_index: &CoordIndex) -> To
                 let activity_type = activity_type.unwrap_or_else(|| "arrival".to_string());
                 let is_break = activity_type == "break";
 
-                let job_tag = act.job.as_ref().and_then(|job| job.dimens.get_value::<String>("tag").cloned());
+                let job_tag = act.job.as_ref().and_then(|single| {
+                    get_job_tag(single, (act.place.location, (act.place.time.clone(), start.schedule.departure)))
+                        .cloned()
+                });
                 let job_id = match activity_type.as_str() {
                     "pickup" | "delivery" | "replacement" | "service" => {
                         let single = act.job.as_ref().unwrap();
                         let id = single.dimens.get_id().cloned();
-                        id.unwrap_or_else(|| Multi::roots(&single).unwrap().dimens.get_id().unwrap().clone())
+                        id.unwrap_or_else(|| Multi::roots(single).unwrap().dimens.get_id().unwrap().clone())
                     }
                     _ => activity_type.clone(),
                 };
